
#!/usr/bin/env python
# -*- encoding: utf8 -*-

import pandas as pd

import warnings
warnings.filterwarnings("ignore")

from jing.x import X
from jing.rule_set import RuleSet
from jing.rule import RuleSimple
from jing.rule import RulePriceBreakout
from jing.rule import RuleVolumeBreakout
from jing.rule import RuleMa50Ma200

pd.set_option('display.max_columns', None)


class Regression:
    def __init__(self) -> None:
        pass

    def breakoutList(self):
        rule = RulePriceBreakout
        l = [
            ["2024-01-19", "SMCI", rule],
            ["2023-10-27", "DECK", rule],
            ["2023-11-30", "CRM", rule],
        ]
        return l

    def ma50Ma200List(self):
        rule = RuleMa50Ma200
        l = [
            [ "2023-10-30", "NFLX", rule],
            [ "2023-11-07", "CRM", rule ],
            [ "2024-01-10", "MDB", rule ],
            [ "2023-11-01", "AMD", rule ],
            [ "2023-11-02", "UBER", rule ],
        ]
        return l

    def volumeBreakoutList(self):
        rule = RuleVolumeBreakout
        l = [
            ["2023-05-24", "ANF", rule],
            ["2024-01-19", "SMCI", rule],
        ]
        return l

    def runOne(self, _list):
        for one in _list:
            dt   = one[0]
            code = one[1]
            rule = one[2]
            print(dt, code, rule)
            x = X("us", dt, code)
            x.add_rule(rule)
            x.run()

    def run(self):
        l = self.breakoutList()
        self.runOne(l)

        l = self.ma50Ma200List()
        self.runOne(l)

        l = self.volumeBreakoutList()
        self.runOne(l)

if __name__=="__main__":
    r = Regression()
    r.run()



#!/usr/bin/env python
# -*- encoding: utf8 -*-

import pandas as pd

import warnings
warnings.filterwarnings("ignore")

from jing.trend import Trend
from jing.y import Y
from jing.rule import RuleSimple

pd.set_option('display.max_columns', None)

class RuleSet:
    def __init__(self, _code, _ref) -> None:
        self.code = _code
        self.ref = _ref
        self.map = {}
        self.result = []

    def add_rule(self, _class):
        self.map[_class.__name__] = _class

    def get_result(self):
        return self.result

    def run(self):
        print('=' * 100)
        for rule_name, a_rule_class in self.map.items():
            print('-' * 100)
            print(f"rule[{rule_name}]")
            rule = a_rule_class(self.code, self.ref)
            good = rule.run()
            if good:
                self.result.append({'rule':rule_name, 'code':self.code})

if __name__=="__main__":
    # x = X("us", "2023-10-30")
    code = "IONQ"
    date = '2024-09-27'

    y = Y("IONQ", _date=date)
    ref = y.ref

    rs = RuleSet(code, ref)
    rs.add_rule(RuleSimple)
    rs.run()

    good = rs.get_result()
    print(good)




from .module1 import my_function
from .module2 import MyClass

from .y import Y
from .x import X

from .rule import Rule
from .rule import RuleSimple
from .rule import RuleMa50Ma200
from .rule import RulePriceBreakout
from .rule import RuleVolumeBreakout

__version__ = "0.1.0"